@@ -98,14 +98,14 @@ class NetworkAndDiskStatsMonitor(Callback):
         new_logs: Dict[str, float] = {}
 
         if self._settings.track_network_utilization:
-            if not hasattr(self, "_net_meter"):
+            if not hasattr(self, "_net_meter") or self._net_meter is None:
                 self._net_meter = NetworkMetrics()
             self._net_meter.update_stats()
             new_logs[LOG_KEY_NETW_BYTES_RECV] = float(self._net_meter.mb_recv_ps.val)
             new_logs[LOG_KEY_NETW_BYTES_SENT] = float(self._net_meter.mb_sent_ps.val)
 
         if self._settings.track_disk_utilization:
-            if not hasattr(self, "_disk_meter"):
+            if not hasattr(self, "_disk_meter") or self._disk_meter is None:
                 self._disk_meter = DiskMetrics()
             self._disk_meter.update_stats()
             new_logs[LOG_KEY_DISK_UTIL] = float(self._disk_meter.io_util.val)
